@@ -18,6 +18,6 @@ cpydata (int in, int out, char *ifile, char *ofile)
 	    adios(ofile, "error writing");
     }
 
-    if (i == NOTOK)
+    if (i == -1)
 	adios(ifile, "error reading");
 }
