@@ -89,7 +89,7 @@ advertise (char *what, char *tail, char *fmt, va_list ap)
 	iov++;
     }
     
-    vsprintf (buffer, fmt, ap);
+    vsnprintf (buffer, BUFSIZ, fmt, ap);
     iov->iov_len = strlen (iov->iov_base = buffer);
     iov++;
     if (what) {
@@ -103,7 +103,7 @@ advertise (char *what, char *tail, char *fmt, va_list ap)
 	}
         if (!(iov->iov_base = strerror (eindex))) {
 	    /* this shouldn't happen, but we'll test for it just in case */
-	    sprintf (err, "Error %d", eindex);
+	    snprintf (err, BUFSIZ, "Error %d", eindex);
 	    iov->iov_base = err;
 	}
 	iov->iov_len = strlen (iov->iov_base);
