@@ -110,13 +110,13 @@ folder_read (char *name)
     }
 
     closedir (dd);
-    mp->lowoff = 1;
+    mp->lowoff = max (mp->lowmsg, 1);
 
     /* Go ahead and allocate space for 100 additional messages. */
-    mp->hghoff = mp->hghmsg + 100;
+    /* mp->hghoff = mp->hghmsg + 100; */
 
     /* for testing, allocate minimal necessary space */
-    /* mp->hghoff = mp->hghmsg; */
+    mp->hghoff = max (mp->hghmsg, 1);
 
     /*
      * Allocate space for status of each message.
