@@ -35,9 +35,8 @@ static int attr (struct msgs *, char *);
 int
 m_convert (struct msgs *mp, char *name)
 {
-    register int first, last;
-    register char *bp, *cp;
-    int found, range, err;
+    int first, last, found, range, err;
+    char *bp, *cp;
 
     /* check if user defined sequence */
     err = attr (mp, cp = name);
@@ -120,7 +119,7 @@ rangerr:
 	    return 0;
 	}
 
-	/* tighten up the range to search */
+	/* tighten the range to search */
 	if (last > mp->hghmsg)
 	    last = mp->hghmsg;
 	if (first < mp->lowmsg)
@@ -146,10 +145,13 @@ rangerr:
 	if ((convdir > 0 && first > mp->hghmsg)
 	    || (convdir < 0 && first < mp->lowmsg))
 	    goto rangerr;
+
+	/* tighten the range to search */
 	if (first < mp->lowmsg)
 	    first = mp->lowmsg;
 	if (first > mp->hghmsg)
 	    first = mp->hghmsg;
+
 	for (last = first;
 	     last >= mp->lowmsg && last <= mp->hghmsg;
 	     last += convdir)
