@@ -84,7 +84,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches] [aliasfiles ...]", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 0);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
