@@ -238,7 +238,7 @@ main (int argc, char **argv)
 
 	    case HELPSW: 
 		snprintf (buf, 100, "%s [+folder] [switches]", invo_name);
-		print_help (buf, switches);
+		print_help (buf, switches, 1);
 		done (1);
 	    case VERSIONSW:
 		print_version(invo_name);
@@ -562,7 +562,7 @@ main (int argc, char **argv)
 		adios (NULL, "unable to fdopen %s", packfile);
 	} else {
 	    hghnum = msgnum = mp->hghmsg;
-	    if (!(mp = folder_realloc (mp, 0, mp->hghmsg + nmsgs)))
+	    if (!(mp = folder_realloc (mp, mp->lowoff, mp->hghmsg + nmsgs)))
 		adios (NULL, "unable to allocate folder storage");
 	}
 
@@ -675,7 +675,7 @@ main (int argc, char **argv)
 	hghnum = msgnum = mp->hghmsg;
 	for (i = 0;;) {
 	    if (msgnum >= mp->hghoff) {
-		if (!(mp = folder_realloc (mp, 0, mp->hghoff + MAXFOLDER))) {
+		if (!(mp = folder_realloc (mp, mp->lowoff, mp->hghoff + MAXFOLDER))) {
 		    advise (NULL, "unable to allocate folder storage");
 		    i = NOTOK;
 		    break;
