@@ -100,7 +100,7 @@ static struct swit mhlswitches[] = {
 #define	ADDRFMT     0x000200	/* contains addresses                */
 #define	BELL        0x000400	/* sound bell at EOP                 */
 #define	DATEFMT     0x000800	/* contains dates                    */
-#define	FORMAT      0x001000	/* parse address/date                */
+#define	FORMAT      0x001000	/* parse address/date/RFC-2047 field */
 #define	INIT        0x002000	/* initialize component              */
 #define	FACEFMT     0x004000	/* contains face                     */
 #define	FACEDFLT    0x008000	/* default for face                  */
@@ -325,7 +325,7 @@ mhl (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches] [files ...]", invo_name);
-		    print_help (buf, mhlswitches);
+		    print_help (buf, mhlswitches, 1);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
@@ -489,11 +489,11 @@ static void
 mhl_format (char *file, int length, int width)
 {
     int i;
-    register char *bp, *cp, **ip;
+    char *bp, *cp, **ip;
     char *ap, buffer[BUFSIZ], name[NAMESZ];
-    register struct mcomp *c1;
+    struct mcomp *c1;
     struct stat st;
-    register FILE *fp;
+    FILE *fp;
     static dev_t dev = 0;
     static ino_t ino = 0;
     static time_t mtime = 0;
@@ -510,8 +510,11 @@ mhl_format (char *file, int length, int width)
     if ((fp = fopen (etcpath (file), "r")) == NULL)
 	adios (file, "unable to open format file");
 
-    if (fstat (fileno (fp), &st) != NOTOK)
-	mtime = st.st_mtime, dev = st.st_dev, ino = st.st_ino;
+    if (fstat (fileno (fp), &st) != NOTOK) {
+	mtime = st.st_mtime;
+	dev = st.st_dev;
+	ino = st.st_ino;
+    }
 
     global.c_ovtxt = global.c_nfs = NULL;
     global.c_fmt = NULL;
@@ -539,12 +542,12 @@ mhl_format (char *file, int length, int width)
 	}
 
 	parptr = bp;
-	strcpy (name, parse ());
+	strcpy (name, parse());
 	switch (*parptr) {
 	    case '\0': 
 	    case ',': 
 	    case '=': 
-		if (uleq (name, "ignores")) {
+		if (!strcasecmp (name, "ignores")) {
 		    ip = copyip (brkstring (getcpy (++parptr), ",", NULL), ip);
 		    continue;
 		}
@@ -596,7 +599,7 @@ mhl_format (char *file, int length, int width)
 	}
     }
 
-out: ;
+out:
     if (clearflg == 1) {
 	global.c_flags |= CLEARSCR;
     } else {
@@ -628,23 +631,23 @@ static int
 evalvar (struct mcomp *c1)
 {
     char *cp, name[NAMESZ];
-    register struct triple *ap;
+    struct triple *ap;
 
     if (!*parptr)
 	return 0;
     strcpy (name, parse ());
 
-    if (uleq (name, "component")) {
+    if (!strcasecmp (name, "component")) {
 	if (ptos (name, &c1->c_text))
 	    return 1;
 	c1->c_flags &= ~NOCOMPONENT;
 	return 0;
     }
 
-    if (uleq (name, "overflowtext"))
+    if (!strcasecmp (name, "overflowtext"))
 	return ptos (name, &c1->c_ovtxt);
 
-    if (uleq (name, "formatfield")) {
+    if (!strcasecmp (name, "formatfield")) {
 	char *nfs;
 
 	if (ptos (name, &cp))
@@ -655,21 +658,30 @@ evalvar (struct mcomp *c1)
 	return 0;
     }
 
-    if (uleq (name, "offset"))
+    if (!strcasecmp (name, "decode")) {
+	char *nfs;
+
+	nfs = new_fs (NULL, NULL, "%(decode{text})");
+	c1->c_nfs = getcpy (nfs);
+	c1->c_flags |= FORMAT;
+	return 0;
+    }
+
+    if (!strcasecmp (name, "offset"))
 	return ptoi (name, &c1->c_offset);
-    if (uleq (name, "overflowoffset"))
+    if (!strcasecmp (name, "overflowoffset"))
 	return ptoi (name, &c1->c_ovoff);
-    if (uleq (name, "width"))
+    if (!strcasecmp (name, "width"))
 	return ptoi (name, &c1->c_width);
-    if (uleq (name, "compwidth"))
+    if (!strcasecmp (name, "compwidth"))
 	return ptoi (name, &c1->c_cwidth);
-    if (uleq (name, "length"))
+    if (!strcasecmp (name, "length"))
 	return ptoi (name, &c1->c_length);
-    if (uleq (name, "nodashmunging"))
+    if (!strcasecmp (name, "nodashmunging"))
 	return (dashflg = 0);
 
     for (ap = triples; ap->t_name; ap++)
-	if (uleq (ap->t_name, name)) {
+	if (!strcasecmp (ap->t_name, name)) {
 	    c1->c_flags |= ap->t_on;
 	    c1->c_flags &= ~ap->t_off;
 	    return 0;
@@ -704,16 +716,17 @@ ptos (char *name, char **s)
 	return 1;
     }
 
-    if (*parptr != '"')
+    if (*parptr != '"') {
 	for (cp = parptr;
 		*parptr && *parptr != ':' && *parptr != ',';
 		parptr++)
 	    continue;
-    else
+    } else {
 	for (cp = ++parptr; *parptr && *parptr != '"'; parptr++)
 	    if (*parptr == QUOTE)
 		if (!*++parptr)
 		    parptr--;
+    }
     c = *parptr;
     *parptr = 0;
     *s = getcpy (cp);
@@ -764,8 +777,7 @@ process (char *folder, char *fname, int ofilen, int ofilec)
 		    exitstat++;
 		    return;
 		}
-	    }
-	    else {
+	    } else {
 		fname = "(stdin)";
 		fp = stdin;
 	    }
@@ -796,9 +808,8 @@ static void
 mhlfile (FILE *fp, char *mname, int ofilen, int ofilec)
 {
     int state;
-    register struct mcomp *c1, *c2, *c3;
-    register char **ip;
-    char name[NAMESZ], buf[BUFSIZ];
+    struct mcomp *c1, *c2, *c3;
+    char **ip, name[NAMESZ], buf[BUFSIZ];
 
     if (forwall) {
 	if (digest)
@@ -811,8 +822,7 @@ mhlfile (FILE *fp, char *mname, int ofilen, int ofilec)
 		printf (" Message %d", ofilen);
 	    printf ("\n\n");
 	}
-    }
-    else
+    } else {
 	switch (ontty) {
 	    case PITTY: 
 		if (ofilec > 1) {
@@ -857,13 +867,14 @@ mhlfile (FILE *fp, char *mname, int ofilen, int ofilec)
 		}
 		break;
 	}
+    }
 
-    for (state = FLD;;)
+    for (state = FLD;;) {
 	switch (state = m_getfld (state, name, buf, sizeof buf, fp)) {
 	    case FLD: 
 	    case FLDPLUS: 
 		for (ip = ignores; *ip; ip++)
-		    if (uleq (name, *ip)) {
+		    if (!strcasecmp (name, *ip)) {
 			while (state == FLDPLUS)
 			    state = m_getfld (state, name, buf, sizeof buf, fp);
 			break;
@@ -872,12 +883,12 @@ mhlfile (FILE *fp, char *mname, int ofilen, int ofilec)
 		    continue;
 
 		for (c2 = fmthd; c2; c2 = c2->c_next)
-		    if (uleq (c2->c_name, name))
+		    if (!strcasecmp (c2->c_name, name))
 			break;
 		c1 = NULL;
 		if (!((c3 = c2 ? c2 : &global)->c_flags & SPLIT))
 		    for (c1 = msghd; c1; c1 = c1->c_next)
-			if (uleq (c1->c_name, c3->c_name)) {
+			if (!strcasecmp (c1->c_name, c3->c_name)) {
 			    c1->c_text =
 				mcomp_add (c1->c_flags, buf, c1->c_text);
 			    break;
@@ -900,7 +911,7 @@ mhlfile (FILE *fp, char *mname, int ofilen, int ofilec)
 			putcomp (c1, c1, ONECOMP);
 			continue;
 		    }
-		    if (uleq (c1->c_name, "messagename")) {
+		    if (!strcasecmp (c1->c_name, "messagename")) {
 			holder.c_text = concat ("(Message ", mname, ")\n",
 					    NULL);
 			putcomp (c1, &holder, ONECOMP);
@@ -908,13 +919,13 @@ mhlfile (FILE *fp, char *mname, int ofilen, int ofilec)
 			holder.c_text = NULL;
 			continue;
 		    }
-		    if (uleq (c1->c_name, "extras")) {
+		    if (!strcasecmp (c1->c_name, "extras")) {
 			for (c2 = msghd; c2; c2 = c2->c_next)
 			    if (c2->c_flags & EXTRA)
 				putcomp (c1, c2, TWOCOMP);
 			continue;
 		    }
-		    if (dobody && uleq (c1->c_name, "body")) {
+		    if (dobody && !strcasecmp (c1->c_name, "body")) {
 			if ((holder.c_text = malloc (sizeof buf)) == NULL)
 			    adios (NULL, "unable to allocate buffer memory");
 			strcpy (holder.c_text, buf);
@@ -928,7 +939,7 @@ mhlfile (FILE *fp, char *mname, int ofilen, int ofilec)
 			continue;
 		    }
 		    for (c2 = msghd; c2; c2 = c2->c_next)
-			if (uleq (c2->c_name, c1->c_name)) {
+			if (!strcasecmp (c2->c_name, c1->c_name)) {
 			    putcomp (c1, c2, ONECOMP);
 			    if (!(c1->c_flags & SPLIT))
 				break;
@@ -956,16 +967,17 @@ mhlfile (FILE *fp, char *mname, int ofilen, int ofilec)
 	    default: 
 		adios (NULL, "getfld() returned %d", state);
 	}
+    }
 }
 
 
 static int
 mcomp_flags (char *name)
 {
-    register struct pair *ap;
+    struct pair *ap;
 
     for (ap = pairs; ap->p_name; ap++)
-	if (uleq (ap->p_name, name))
+	if (!strcasecmp (ap->p_name, name))
 	    return (ap->p_flags);
 
     return 0;
@@ -975,7 +987,7 @@ mcomp_flags (char *name)
 static char *
 mcomp_add (long flags, char *s1, char *s2)
 {
-    register char *dp;
+    char *dp;
 
     if (!(flags & ADDRFMT))
 	return add (s1, s2);
@@ -998,17 +1010,20 @@ static void
 mcomp_format (struct mcomp *c1, struct mcomp *c2)
 {
     int dat[5];
-    register char *ap, *cp;
+    char *ap, *cp;
     char buffer[BUFSIZ], error[BUFSIZ];
-    register struct comp *cptr;
-    register struct pqpair *p, *q;
+    struct comp *cptr;
+    struct pqpair *p, *q;
     struct pqpair pq;
-    register struct mailname *mp;
+    struct mailname *mp;
 
     ap = c2->c_text;
     c2->c_text = NULL;
-    dat[0] = dat[1] = dat[2] = dat[4] = 0;
-    dat[3] = sizeof buffer - 1;
+    dat[0] = 0;
+    dat[1] = 0;
+    dat[2] = 0;
+    dat[3] = sizeof(buffer) - 1;
+    dat[4] = 0;
     fmt_compile (c1->c_nfs, &c1->c_fmt);
 
     if (!(c1->c_flags & ADDRFMT)) {
@@ -1035,8 +1050,7 @@ mcomp_format (struct mcomp *c1, struct mcomp *c2)
 	if ((mp = getm (cp, NULL, 0, AD_NAME, error)) == NULL) {
 	    p->pq_text = getcpy (cp);
 	    p->pq_error = getcpy (error);
-	}
-	else {
+	} else {
 	    if ((c1->c_flags & FACEDFLT) && c2->c_face == NULL) {
 		char   *h, *o;
 		if ((h = mp->m_host) == NULL)
@@ -1084,7 +1098,7 @@ mcomp_format (struct mcomp *c1, struct mcomp *c2)
 static struct mcomp *
 add_queue (struct mcomp **head, struct mcomp **tail, char *name, char *text, int flags)
 {
-    register struct mcomp *c1;
+    struct mcomp *c1;
 
     if ((c1 = (struct mcomp *) calloc ((size_t) 1, sizeof *c1)) == NULL)
 	adios (NULL, "unable to allocate comp memory");
@@ -1115,7 +1129,7 @@ add_queue (struct mcomp **head, struct mcomp **tail, char *name, char *text, int
 static void
 free_queue (struct mcomp **head, struct mcomp **tail)
 {
-    register struct mcomp *c1, *c2;
+    struct mcomp *c1, *c2;
 
     for (c1 = *head; c1; c1 = c2) {
 	c2 = c1->c_next;
@@ -1142,7 +1156,7 @@ static void
 putcomp (struct mcomp *c1, struct mcomp *c2, int flag)
 {
     int count, cchdr;
-    register char *cp;
+    char *cp;
 
     cchdr = 0;
     lm = 0;
@@ -1182,10 +1196,10 @@ putcomp (struct mcomp *c1, struct mcomp *c2, int flag)
 	if (!(c1->c_flags & HDROUTPUT) && !(c1->c_flags & NOCOMPONENT))
 	    count -= strlen (c1->c_text ? c1->c_text : c1->c_name) + 2;
 	lm = c1->c_offset + (count / 2);
-    }
-    else
+    } else {
 	if (c1->c_offset)
 	    lm = c1->c_offset;
+    }
 
     if (!(c1->c_flags & HDROUTPUT) && !(c1->c_flags & NOCOMPONENT)) {
         if (c1->c_flags & UPPERCASE)		/* uppercase component also */
@@ -1261,7 +1275,7 @@ static char *
 oneline (char *stuff, long flags)
 {
     int spc;
-    register char *cp, *ret;
+    char *cp, *ret;
 
     if (onelp == NULL)
 	onelp = stuff;
@@ -1434,8 +1448,8 @@ quitser (int i)
 static void
 face_format (struct mcomp *c1)
 {
-    register char *cp;
-    register struct mailname *mp;
+    char *cp;
+    struct mailname *mp;
 
     if ((cp = c1->c_text) == NULL)
 	return;
@@ -1475,7 +1489,7 @@ doface (struct mcomp *c1)
 {
     int	result, sd;
     struct sockaddr_in in_socket;
-    register struct sockaddr_in *isock = &in_socket;
+    struct sockaddr_in *isock = &in_socket;
     static int inited = OK;
     static int addrlen;
     static struct in_addr addr;
@@ -1528,10 +1542,10 @@ bad_faceproc: ;
 static int
 doface (struct mcomp *c1)
 {
-    register int i, len, vecp;
+    int i, len, vecp;
     pid_t child_id;
     int result, pdi[2], pdo[2];
-    register char *bp, *cp;
+    char *bp, *cp;
     char buffer[BUFSIZ], *vec[10];
 
     if (pipe (pdi) == NOTOK)
@@ -1592,8 +1606,8 @@ doface (struct mcomp *c1)
 	    result = DONE;
 	    while ((i = read (pdo[0], buffer, strlen (buffer))) > 0) {
 		if (cp) {
-		    register int    j;
-		    register char  *dp;
+		    int j;
+		    char *dp;
 		    if ((dp = realloc (cp, (unsigned) (j = len + i))) == NULL)
 			adios (NULL, "unable to allocate face storage");
 		    memcpy(dp + len, buffer, i);
