@@ -59,9 +59,7 @@ static void show (int);
 static int eom_action (int);
 static FILE *mhl_action (char *);
 static int ask (int);
-#ifdef MIME
-static int nontext (int);
-#endif
+static int is_nontext (int);
 static int getws (char *, char *, int, struct Msg *);
 static int msgsort (struct Msg *, struct Msg *);
 static int subsort (struct Msg *, struct Msg *);
@@ -167,7 +165,7 @@ distcmd (char **args)
 		    return;
 		case DIHELP: 
 		    sprintf (buf, "%s [msgs] [switches]", cmd_name);
-		    print_help (buf, distswit);
+		    print_help (buf, distswit, 1);
 		    return;
 
 		case DIANSW:	/* not implemented */
@@ -269,7 +267,7 @@ explcmd (char **args)
 		    return;
 		case EXHELP: 
 		    sprintf (buf, "%s [msgs] [switches]", cmd_name);
-		    print_help (buf, explswit);
+		    print_help (buf, explswit, 1);
 		    return;
 
 		case EXINSW: 
@@ -401,7 +399,7 @@ burst (struct Msg *smsgs, int msgnum, int inplace, int quietsw, int verbosw)
 	advise (NULL, "more than %d messages", MAXFOLDER);
 	return NOTOK;
     }
-    if (!(mp = folder_realloc (mp, 0, i)))
+    if (!(mp = folder_realloc (mp, mp->lowoff, i)))
 	adios (NULL, "unable to allocate folder storage");
 
     j = mp->hghmsg;
@@ -498,7 +496,7 @@ filecmd (char **args)
 		    return;
 		case FIHELP: 
 		    sprintf (buf, "%s +folder... [msgs] [switches]", cmd_name);
-		    print_help (buf, fileswit);
+		    print_help (buf, fileswit, 1);
 		    return;
 
 		case FILINK:
@@ -660,7 +658,7 @@ foldcmd (char **args)
 		    return;
 		case FLHELP: 
 		    sprintf (buf, "%s [+folder] [msg] [switches]", cmd_name);
-		    print_help (buf, foldswit);
+		    print_help (buf, foldswit, 1);
 		    return;
 
 		case FLALSW:	/* not implemented */
@@ -759,8 +757,9 @@ foldcmd (char **args)
 	    return;
 	}
 
-	if (mp->lowmsg > 1 && !(mp = folder_realloc (mp, 1, mp->hghmsg)))
+	if (mp->lowoff > 1 && !(mp = folder_realloc (mp, 1, mp->hghmsg)))
 	    adios (NULL, "unable to allocate folder storage");
+
 	for (msgnum = mp->lowmsg, hole = 1; msgnum <= mp->hghmsg; msgnum++)
 	    if (does_exist (mp, msgnum)) {
 		if (msgnum != hole) {
@@ -812,12 +811,6 @@ fast: ;
 }
 
 
-#ifndef	MIME
-# define MIMEminc(a) (a)
-#else	/* MIME */
-# define MIMEminc(a)  0
-#endif	/* MIME */
-
 static struct swit forwswit[] = {
 #define	FOANSW                   0
     { "annotate", 0 },
@@ -846,9 +839,9 @@ static struct swit forwswit[] = {
 #define	FONINSW                 12
     { "noinplace", 0 },
 #define	FOMISW                  13
-    { "mime", MIMEminc(-4) },
+    { "mime", 0 },
 #define	FONMISW                 14
-    { "nomime", MIMEminc(-6) },
+    { "nomime", 0 },
 #define	FOWHTSW                 15
     { "whatnowproc program", 0 },
 #define	FONWTSW                 16
@@ -882,7 +875,7 @@ forwcmd (char **args)
 		    return;
 		case FOHELP: 
 		    sprintf (buf, "%s [msgs] [switches]", cmd_name);
-		    print_help (buf, forwswit);
+		    print_help (buf, forwswit, 1);
 		    return;
 
 		case FOANSW:	/* not implemented */
@@ -1140,7 +1133,7 @@ markcmd (char **args)
 		    return;
 		case MHELP: 
 		    sprintf (buf, "%s [msgs] [switches]", cmd_name);
-		    print_help (buf, markswit);
+		    print_help (buf, markswit, 1);
 		    return;
 
 		case MADDSW: 
@@ -1268,7 +1261,7 @@ markcmd (char **args)
 			    DMAXFOLDER, msgnum,
 			    Msgs[msgnum].m_bboard_id, Msgs[msgnum].m_top,
 			    Msgs[msgnum].m_start, Msgs[msgnum].m_stop,
-			    snprintb (buf, BUFSIZ, (unsigned) mp->msgstats[msgnum],
+			    snprintb (buf, BUFSIZ, (unsigned) mp->msgstats[msgnum - mp->lowoff],
 				seq_bits (mp)));
 		    if (Msgs[msgnum].m_scanl)
 			printf ("%s", Msgs[msgnum].m_scanl);
@@ -1277,7 +1270,6 @@ markcmd (char **args)
 }
 
 
-#ifdef MIME
 static struct swit mhnswit[] = {
 #define	MHNAUTOSW	    0
     { "auto", 0 },
@@ -1353,9 +1345,8 @@ mhncmd (char **args)
 	forkcmd (args, cmd_name);
 	return;
     }
-
     while ((cp = *args++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, mhnswit)) {
 		case AMBIGSW: 
 		    ambigsw (cp, mhnswit);
@@ -1365,7 +1356,7 @@ mhncmd (char **args)
 		    return;
 		case MHNHELPSW:
 		    sprintf (buf, "%s [msgs] [switches]", cmd_name);
-		    print_help (buf, mhnswit);
+		    print_help (buf, mhnswit, 1);
 		    return;
 
 		case MHNAUTOSW:
@@ -1407,12 +1398,13 @@ mhncmd (char **args)
 		    vec[vecp++] = cp;
 		    continue;
 	    }
+	}
 	if (*cp == '+' || *cp == '@') {
 	    advise (NULL, "sorry, no folders allowed!");
 	    return;
-	}
-	else
+	} else {
 	    msgs[msgp++] = cp;
+	}
     }
 
     vec[0] = cmd_name;
@@ -1438,7 +1430,6 @@ mhncmd (char **args)
     seq_setcur (mp, mp->hghsel);
 }
 
-#endif /* MIME */
 
 static struct swit packswit[] = {
 #define	PAFISW         0
@@ -1474,7 +1465,7 @@ packcmd (char **args)
 		    return;
 		case PAHELP: 
 		    sprintf (buf, "%s [msgs] [switches]", cmd_name);
-		    print_help (buf, packswit);
+		    print_help (buf, packswit, 1);
 		    return;
 
 		case PAFISW: 
@@ -1651,7 +1642,7 @@ pickcmd (char **args)
 		    return;
 		case PIHELP: 
 		    sprintf (buf, "%s [msgs] [switches]", cmd_name);
-		    print_help (buf, pickswit);
+		    print_help (buf, pickswit, 1);
 		    return;
 
 		case PICCSW: 
@@ -1837,7 +1828,7 @@ replcmd (char **args)
 		    return;
 		case REHELP: 
 		    sprintf (buf, "%s [msgs] [switches]", cmd_name);
-		    print_help (buf, replswit);
+		    print_help (buf, replswit, 1);
 		    return;
 
 		case REANSW:	/* not implemented */
@@ -1927,7 +1918,7 @@ rmmcmd (char **args)
 		    return;
 		case RMHELP: 
 		    sprintf (buf, "%s [msgs] [switches]", cmd_name);
-		    print_help (buf, rmmswit);
+		    print_help (buf, rmmswit, 1);
 		    return;
 	    }
 	if (*cp == '+' || *cp == '@') {
@@ -2068,7 +2059,7 @@ scancmd (char **args)
 		    return;
 		case SCHELP: 
 		    sprintf (buf, "%s [msgs] [switches]", cmd_name);
-		    print_help (buf, scanswit);
+		    print_help (buf, scanswit, 1);
 		    return;
 
 		case SCCLR: 
@@ -2297,10 +2288,10 @@ showcmd (char **args)
     char *cp, *proc = showproc, buf[BUFSIZ];
     char *msgs[MAXARGS], *vec[MAXARGS];
 
-    if (uleq (cmd_name, "next"))
+    if (!strcasecmp (cmd_name, "next"))
 	mode = 1;
     else
-	if (uleq (cmd_name, "prev"))
+	if (!strcasecmp (cmd_name, "prev"))
 	    mode = -1;
     while ((cp = *args++)) {
 	if (*cp == '-')
@@ -2315,7 +2306,7 @@ showcmd (char **args)
 		case SHHELP: 
 		    sprintf (buf, "%s %s[switches] [switches for showproc]",
 			    cmd_name, mode ? NULL : "[msgs] ");
-		    print_help (buf, showswit);
+		    print_help (buf, showswit, 1);
 		    return;
 
 		case SHFORM: 
@@ -2373,17 +2364,15 @@ showcmd (char **args)
 	    return;
     seq_setprev (mp);
 
-#ifdef MIME
     if (!nshow && !getenv ("NOMHNPROC"))
 	for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-	    if (is_selected (mp, msgnum) && nontext (msgnum)) {
+	    if (is_selected (mp, msgnum) && is_nontext (msgnum)) {
 		proc = showmimeproc;
 		vec[vecp++] = "-show";
 		vec[vecp++] = "-file";
 		vec[vecp] = NULL;
 		goto finish;
 	    }
-#endif /* MIME */
 
     if (nshow)
 	proc = catproc;
@@ -2531,16 +2520,14 @@ ask (int msgnum)
 }
 
 
-#ifdef MIME
 #include <h/mhn.h>
 
-
 static int
-nontext (int msgnum)
+is_nontext (int msgnum)
 {
     int	result, state;
-    register char *bp, *dp;
-    char *chset, *cp, buf[BUFSIZ], name[NAMESZ];
+    char *bp, *cp, *dp;
+    char buf[BUFSIZ], name[NAMESZ];
     FILE *fp;
 
     if (Msgs[msgnum].m_flags & MHNCHK)
@@ -2549,74 +2536,75 @@ nontext (int msgnum)
 
     fp = msh_ready (msgnum, 1);
 
-    if (!(chset = getenv ("MM_CHARSET")))
-	chset = "us-ascii";
-
     for (state = FLD;;)
 	switch (state = m_getfld (state, name, buf, sizeof buf, fp)) {
-	    case FLD:
-	    case FLDPLUS:
-	    case FLDEOF:
-	        if (uleq (name, TYPE_FIELD)) {
-		    int	    passno;
-		    char    c;
+	case FLD:
+	case FLDPLUS:
+	case FLDEOF:
+	    /*
+	     * Check Content-Type field
+	     */
+	    if (!strcasecmp (name, TYPE_FIELD)) {
+		int passno;
+		char c;
 
-		    cp = add (buf, NULL);
-		    while (state == FLDPLUS) {
-			state = m_getfld (state, name, buf, sizeof buf, fp);
-			cp = add (buf, cp);
-		    }
-		    bp = cp;
-		    passno = 1;
+		cp = add (buf, NULL);
+		while (state == FLDPLUS) {
+		    state = m_getfld (state, name, buf, sizeof buf, fp);
+		    cp = add (buf, cp);
+		}
+		bp = cp;
+		passno = 1;
 
-again: ;
-		    for (; isspace (*bp); bp++)
-			continue;
-		    if (*bp == '(') {
-			int	i;
+again:
+		for (; isspace (*bp); bp++)
+		    continue;
+		if (*bp == '(') {
+		    int	i;
 
-			for (bp++, i = 0;;) {
-			    switch (*bp++) {
-				case '\0':
-invalid: ;
-				    result = 0;
-				    goto out;
-				case '\\':
-				    if (*bp++ == '\0')
-					goto invalid;
-    				    continue;
-				case '(':
-    				    i++;
-    				    /* and fall... */
-    				default:
-    				    continue;
-    				case ')':
-    				    if (--i < 0)
-					break;
-				continue;
-			    }
-			    break;
-			}
-		    }
-		    if (passno == 2) {
-			if (*bp != '/')
-			    goto invalid;
-			bp++;
-			passno = 3;
-			goto again;
-		    }
-		    for (dp = bp; istoken (*dp); dp++)
-			continue;
-		    c = *dp;
-		    *dp = '\0';
-		    if (!*bp)
-			goto invalid;
-		    if (passno > 1) {
-			if ((result = !uleq (bp, "plain")))
+		    for (bp++, i = 0;;) {
+			switch (*bp++) {
+			case '\0':
+invalid:
+			    result = 0;
 			    goto out;
-			*dp = c;
-			for (dp++; isspace (*dp); dp++)
+			case '\\':
+			    if (*bp++ == '\0')
+				goto invalid;
 			    continue;
+			case '(':
+			    i++;
+			    /* and fall... */
+			default:
+			    continue;
+			case ')':
+			    if (--i < 0)
+				break;
+			    continue;
+			}
+			break;
+		    }
+		}
+		if (passno == 2) {
+		    if (*bp != '/')
+			goto invalid;
+		    bp++;
+		    passno = 3;
+		    goto again;
+		}
+		for (dp = bp; istoken (*dp); dp++)
+		    continue;
+		c = *dp;
+		*dp = '\0';
+		if (!*bp)
+		    goto invalid;
+		if (passno > 1) {
+		    if ((result = (strcasecmp (bp, "plain") != 0)))
+			goto out;
+		    *dp = c;
+		    for (dp++; isspace (*dp); dp++)
+			continue;
+		    if (*dp) {
 			if ((result = !uprf (dp, "charset")))
 			    goto out;
 			dp += sizeof "charset" - 1;
@@ -2629,66 +2617,78 @@ invalid: ;
 			if (*dp == '"') {
 			    if ((bp = strchr(++dp, '"')))
 				*bp = '\0';
-			}
-			else
+			} else {
 			    for (bp = dp; *bp; bp++)
 				if (isspace (*bp)) {
 				    *bp = '\0';
 				    break;
 				}
-			if ((result = !uleq (dp, chset))
-			        && uleq (dp, "us-ascii")
-			        && uleq (chset, "iso-8859-1"))
-			    result = 0;
-		    }
-		    else
-			if (!(result = !uleq (bp, "text"))) {
-			    *dp = c;
-			    bp = dp;
-			    passno = 2;
-			    goto again;
 			}
-
-out: ;
-		    free (cp);
-
-		    if (result) {
-			Msgs[msgnum].m_flags |= MHNYES;
-			return result;
+		    } else {
+			/* Default character set */
+			dp = "US-ASCII";
+		    }
+		    /* Check the character set */
+		    result = !check_charset (dp, strlen (dp));
+		} else {
+		    if (!(result = (strcasecmp (bp, "text") != 0))) {
+			*dp = c;
+			bp = dp;
+			passno = 2;
+			goto again;
 		    }
-		    break;
 		}
-	        if (uleq (name, ENCODING_FIELD)) {
-		    cp = add (buf, NULL);
-		    while (state == FLDPLUS) {
-			state = m_getfld (state, name, buf, sizeof buf, fp);
-			cp = add (buf, cp);
-		    }
-		    for (bp = cp; isspace (*bp); bp++)
-			continue;
-		    for (dp = bp; istoken (*dp); dp++)
-			continue;
-		    *dp = '\0';
-		    result = !uleq (bp, "7bit")
-				&& !uleq (bp, "8bit")
-				&& !uleq (bp, "binary");
-
-		    free (cp);
-		    if (result) {
-			Msgs[msgnum].m_flags |= MHNYES;
-			return result;
-		    }
-		    break;
+out:
+		free (cp);
+		if (result) {
+		    Msgs[msgnum].m_flags |= MHNYES;
+		    return result;
 		}
-		while (state == FLDPLUS)
-		    state = m_getfld (state, name, buf, sizeof(buf), fp);
 		break;
+	    }
 
-	    default:
-		return 0;
+	    /*
+	     * Check Content-Transfer-Encoding field
+	     */
+	    if (!strcasecmp (name, ENCODING_FIELD)) {
+		cp = add (buf, NULL);
+		while (state == FLDPLUS) {
+		    state = m_getfld (state, name, buf, sizeof buf, fp);
+		    cp = add (buf, cp);
+		}
+		for (bp = cp; isspace (*bp); bp++)
+		    continue;
+		for (dp = bp; istoken (*dp); dp++)
+		    continue;
+		*dp = '\0';
+		result = (strcasecmp (bp, "7bit")
+		       && strcasecmp (bp, "8bit")
+		       && strcasecmp (bp, "binary"));
+
+		free (cp);
+		if (result) {
+		    Msgs[msgnum].m_flags |= MHNYES;
+		    return result;
+		}
+		break;
+	    }
+
+	    /*
+	     * Just skip the rest of this header
+	     * field and go to next one.
+	     */
+	    while (state == FLDPLUS)
+		state = m_getfld (state, name, buf, sizeof(buf), fp);
+	    break;
+
+	    /*
+	     * We've passed the message header,
+	     * so message is just text.
+	     */
+	default:
+	    return 0;
 	}
 }
-#endif /* MIME */
 
 
 static struct swit sortswit[] = {
@@ -2736,7 +2736,7 @@ sortcmd (char **args)
 		    return;
 		case SOHELP: 
 		    sprintf (buf, "%s [msgs] [switches]", cmd_name);
-		    print_help (buf, sortswit);
+		    print_help (buf, sortswit, 1);
 		    return;
 
 		case SODATE: 
@@ -2805,7 +2805,7 @@ sortcmd (char **args)
 	}
 	else			/* m_scaln is already NULL */
 	    twscopy (&Msgs[msgnum].m_tb, &tb);
-	Msgs[msgnum].m_stats = mp->msgstats[msgnum];
+	Msgs[msgnum].m_stats = mp->msgstats[msgnum - mp->lowoff];
 	if (mp->curmsg == msgnum)
 	    Msgs[msgnum].m_stats |= CUR;
     }
@@ -2818,7 +2818,7 @@ sortcmd (char **args)
 	    free (Msgs[msgnum].m_scanl);	/* from subjsort */
 	    Msgs[msgnum].m_scanl = NULL;
 	}
-	mp->msgstats[msgnum] = Msgs[msgnum].m_stats & ~CUR;
+	mp->msgstats[msgnum - mp->lowoff] = Msgs[msgnum].m_stats & ~CUR;
 	if (Msgs[msgnum].m_stats & CUR)
 	    seq_setcur (mp, msgnum);
     }
@@ -2847,7 +2847,7 @@ getws (char *datesw, char *subjsw, int msgnum, struct Msg *msgp)
 	    case FLD: 
 	    case FLDEOF: 
 	    case FLDPLUS: 
-		if (uleq (name, datesw)) {
+		if (!strcasecmp (name, datesw)) {
 		    bp = getcpy (buf);
 		    while (state == FLDPLUS) {
 			state = m_getfld (state, name, buf, sizeof buf, zp);
@@ -2864,7 +2864,7 @@ getws (char *datesw, char *subjsw, int msgnum, struct Msg *msgp)
 			break;		/* all done! */
 		    gotdate++;
 		}
-		else if (subjsw && uleq(name, subjsw)) {
+		else if (subjsw && !strcasecmp(name, subjsw)) {
 		    bp = getcpy (buf);
 		    while (state == FLDPLUS) {
 			state = m_getfld (state, name, buf, sizeof buf, zp);
@@ -2944,7 +2944,7 @@ sosmash (char *subj, char *s)
     if (s) {
 	cp = s;
 	dp = s;	/* dst pointer */
-	if (uleq (subj, "subject"))
+	if (!strcasecmp (subj, "subject"))
 	    while ((c = *cp)) {
 		if (! isspace(c)) {
 		    if(uprf(cp, "re:"))
