@@ -11,6 +11,7 @@
 #include <h/addrsbr.h>
 #include <h/aliasbr.h>
 #include <h/dropsbr.h>
+#include <h/mhn.h>
 
 #include <zotnet/tws/tws.h>
 #include <zotnet/mts/mts.h>
@@ -36,22 +37,12 @@
 # include <mts/smtp/smtp.h>
 #endif
 
-#ifdef MIME
-# include <h/mhn.h>
-#endif
-
 #ifndef	MMDFMTS
 # define uptolow(c) ((isalpha(c) && isupper (c)) ? tolower (c) : (c))
 #endif
 
 #define FCCS		10	/* max number of fccs allowed */
 
-#ifndef	MIME
-# define MIMEminc(a)	(a)
-#else
-# define MIMEminc(a)	0
-#endif
-
 static struct swit switches[] = {
 #define	ALIASW                    0
     { "alias aliasfile", 0 },
@@ -74,9 +65,9 @@ static struct swit switches[] = {
 #define	LIBSW                     9
     { "library directory", -7 },	/* interface from send, whom */
 #define	MIMESW                   10
-    { "mime", MIMEminc(-4) },
+    { "mime", 0 },
 #define	NMIMESW                  11
-    { "nomime", MIMEminc(-6) },
+    { "nomime", 0 },
 #define	MSGDSW                   12
     { "msgid", 0 },
 #define	NMSGDSW                  13
@@ -106,15 +97,15 @@ static struct swit switches[] = {
 #define	SOMLSW                   25
     { "soml", -4 },			/* specify SOML smtp mode */
 #define	ANNOSW                   26
-    { "idanno number", -6 },		/* interface from send */
+    { "idanno number", -6 },		/* interface from send    */
 #define	DLVRSW                   27
     { "deliver address-list", -7 },
 #define	CLIESW                   28
     { "client host", -6 },
 #define	SERVSW                   29
-    { "server host", -6 },
+    { "server host", -6 },		/* specify alternate SMTP server */
 #define	SNOOPSW                  30
-    { "snoop", -5 },
+    { "snoop", -5 },			/* snoop the SMTP transaction */
 #define	FILLSW                   31
     { "fill-in file", -7 },
 #define	FILLUSW                  32
@@ -263,9 +254,7 @@ static char *serversw = NULL;
 extern struct smtp sm_reply;
 #endif /* SENDMTS */
 
-#ifdef MIME
 static char prefix[] = "----- =_aaaaaaaaaa";
-#endif
 
 static int fill_up = 0;
 static char *fill_in = NULL;
@@ -298,10 +287,7 @@ static void post (char *, int, int);
 static void do_text (char *file, int fd);
 static void do_an_address (struct mailname *, int);
 static void do_addresses (int, int);
-
-#ifdef MIME
 static int find_prefix (void);
-#endif
 
 
 int
@@ -338,7 +324,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buf, "%s [switches] file", invo_name);
-		    print_help (buf, switches);
+		    print_help (buf, switches, 0);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
@@ -392,10 +378,8 @@ main (int argc, char **argv)
 		    continue;
 
 		case MIMESW:
-#ifdef MIME
 		    mime++;
 		    filter = NULL;
-#endif
 		    continue;
 		case NMIMESW: 
 		    mime = 0;
@@ -894,7 +878,7 @@ get_header (char *header, struct headers *table)
     struct headers *h;
 
     for (h = table; h->value; h++)
-	if (uleq (header, h->value))
+	if (!strcasecmp (header, h->value))
 	    return (h - table);
 
     return NOTOK;
@@ -992,8 +976,8 @@ insert (struct mailname *np)
 	    : &netaddrs;
 	    mp->m_next;
 	    mp = mp->m_next)
-	if (uleq (np->m_host, mp->m_next->m_host)
-		&& uleq (np->m_mbox, mp->m_next->m_mbox)
+	if (!strcasecmp (np->m_host, mp->m_next->m_host)
+		&& !strcasecmp (np->m_mbox, mp->m_next->m_mbox)
 		&& np->m_bcc == mp->m_next->m_bcc)
 	    return 0;
 
@@ -1116,7 +1100,6 @@ make_bcc_file (void)
 	fprintf (out, "Subject: %s", subject);
     fprintf (out, "BCC:\n");
 
-#ifdef MIME
     /*
      * Use MIME encapsulation for Bcc messages
      */
@@ -1137,9 +1120,9 @@ make_bcc_file (void)
 	fprintf (out, "%s: %s\n%s: multipart/digest; boundary=\"",
 		 VRSN_FIELD, VRSN_VALUE, TYPE_FIELD);
 	fprintf (out, "%s\"\n\n--%s\n\n", prefix, prefix);
-    } else
-#endif /* MIME */
+    } else {
 	fprintf (out, "\n------- Blind-Carbon-Copy\n\n");
+    }
 
     fflush (out);
 
@@ -1178,27 +1161,22 @@ make_bcc_file (void)
     } else {
 	if ((fd = open (tmpfil, O_RDONLY)) == NOTOK)
 	    adios (tmpfil, "unable to re-open");
-#ifdef MIME
 	if (mime)
 	    cpydata (fd, fileno (out), tmpfil, bccfil);
 	else
-#endif /* MIME */
 	    cpydgst (fd, fileno (out), tmpfil, bccfil);
 	close (fd);
     }
 
     fseek (out, 0L, SEEK_END);
-#ifdef MIME
     if (mime)
 	fprintf (out, "\n--%s--\n", prefix);
     else
-#endif /* MIME */
 	fprintf (out, "\n------- End of Blind-Carbon-Copy\n");
     fclose (out);
 }
 
 
-#ifdef MIME
 static int
 find_prefix (void)
 {
@@ -1230,14 +1208,13 @@ find_prefix (void)
 	
     return result;
 }
-#endif /* MIME */
 
 
+#define	plural(x) (x == 1 ? "" : "s")
+
 static void
 chkadr (void)
 {
-#define	plural(x) (x == 1 ? "" : "s")
-
     if (badadr && unkadr)
 	die (NULL, "%d address%s unparsable, %d addressee%s undeliverable",
 		badadr, plural (badadr), unkadr, plural (badadr));
@@ -1310,9 +1287,10 @@ do_addresses (int bccque, int talk)
 static void
 post (char *file, int bccque, int talk)
 {
-    int fd, onex = !(msgflags & MINV) || bccque;
+    int fd, onex;
     int	retval;
 
+    onex = !(msgflags & MINV) || bccque;
     if (verbose) {
 	if (msgflags & MINV)
 	    printf (" -- Posting for %s Recipients --\n",
@@ -1498,13 +1476,14 @@ do_text (char *file, int fd)
 static void
 post (char *file, int bccque, int talk)
 {
-    int fd, onex = !(msgflags & MINV) || bccque;
+    int fd, onex;
     int	retval;
 #ifdef RP_NS
     int	len;
     struct rp_bufstruct reply;
 #endif /* RP_NS */
 
+    onex = !(msgflags & MINV) || bccque;
     if (verbose) {
 	if (msgflags & MINV)
 	    printf (" -- Posting for %s Recipients --\n",
