@@ -59,7 +59,7 @@ main (int argc, char **argv)
 
 		case HELPSW: 
 		    sprintf (buffer, "%s [switches]", invo_name);
-		    print_help (buffer, switches);
+		    print_help (buffer, switches, 0);
 		    done (1);
 		case VERSIONSW:
 		    print_version(invo_name);
